/**
    Centerpoint: Konstruktion Spielfeld. Wird in orxoblox.oxw definiert.
*/


/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabian 'x3n' Landau
 *   Co-authors:
 *      ...
 *
 */

/**
    @file OrxoBloxCenterpoint.cc
    @brief Implementation of the OrxoBloxCenterpoint class.
*/

#include "OrxoBloxCenterpoint.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"

#include "OrxoBlox.h"

namespace orxonox
{
    RegisterClass(OrxoBloxCenterpoint);

    /**
    @brief
        Constructor. Registers and initializes the object and checks whether the gametype is actually OrxoBlox.
    */
    OrxoBloxCenterpoint::OrxoBloxCenterpoint(Context* context) : StaticEntity(context)
    {
        RegisterObject(OrxoBloxCenterpoint);

        this->width_ = 200;
        this->height_ = 120;
        this->ballspeed_ = 60;
        this->ballaccfactor_ = 1.0;
        this->batspeed_ = 60;
        this->batlength_ = 0.25;

        this->checkGametype();
    }

    /**
    @brief
        Method to create a OrxoBloxCenterpoint through XML.
    */
    void OrxoBloxCenterpoint::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(OrxoBloxCenterpoint, XMLPort, xmlelement, mode);

        XMLPortParam(OrxoBloxCenterpoint, "dimension", setFieldDimension, getFieldDimension, xmlelement, mode);
        XMLPortParam(OrxoBloxCenterpoint, "balltemplate", setBalltemplate, getBalltemplate, xmlelement, mode);
        XMLPortParam(OrxoBloxCenterpoint, "battemplate", setBattemplate, getBattemplate, xmlelement, mode);
        XMLPortParam(OrxoBloxCenterpoint, "ballspeed", setBallSpeed, getBallSpeed, xmlelement, mode);
        XMLPortParam(OrxoBloxCenterpoint, "ballaccfactor", setBallAccelerationFactor, getBallAccelerationFactor, xmlelement, mode);
        XMLPortParam(OrxoBloxCenterpoint, "batspeed", setBatSpeed, getBatSpeed, xmlelement, mode);
        XMLPortParam(OrxoBloxCenterpoint, "batlength", setBatLength, getBatLength, xmlelement, mode);
    }

    /**
    @brief
        Checks whether the gametype is OrxoBlox and if it is, sets its centerpoint.
    */
    void OrxoBloxCenterpoint::checkGametype()
    {
        if (this->getGametype() != nullptr && this->getGametype()->isA(Class(OrxoBlox)))
        {
            OrxoBlox* OrxoBloxGametype = orxonox_cast<OrxoBlox*>(this->getGametype());
            OrxoBloxGametype->setCenterpoint(this);
        }
    }
}
